// CaseCodeLabel.cs : Implementation of a sample label using C# and 
// Morovia Barcode DLL.
//
// This file is part of the Morovia Barcode DLL package.
// (c)2006 Morovia Corporation. All rights reserved.
//
// THIS SOURCE FILE IS THE PROPERTY OF MOROVIA CORPORATION AND IS NOT TO 
// BE RE-DISTRIBUTED BY ANY MEANS WHATSOEVER WITHOUT THE EXPRESSED 
// WRITTEN CONSENT OF MOROVIA.
//
// THIS SOURCE CODE CAN ONLY BE USED UNDER THE TERMS AND CONDITIONS 
// OUTLINED IN THE MOROVIA BARCODE COMPONENT LICENSE AGREEMENT.  MOROVIA 
// GRANTS TO YOU (ONE SOFTWARE DEVELOPER) THE LIMITED RIGHT TO USE 
// THIS SOFTWARE ON A SINGLE COMPUTER.
//
// MOROVIA EXPRESSLY DISCLAIMS ANY WARRANTY FOR THE SOFTWARE, DOCUMENTATION
// AND ANYTHING ELSE PROVIDED BY MOROVIA HEREBY AND MOROVIA PROVIDES THE 
// SAME IN "AS IS" CONDITION WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESS
// OR IMPLIED, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF 
// MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. THE ENTIRE RISK 
// ARISING OUT OF USE OR PERFORMANCE OF THE SOFTWARE AND DOCUMENTATION 
// REMAINS WITH YOU. 
//
// CONTACT INFORMATION:
// support@morovia.com
// http://www.morovia.com
////////////////////////////////////////////////////////////// 


using System;
using System.Collections;
using System.Drawing;
using System.Drawing.Printing;
using System.Windows.Forms;

// case label structure
/*----------------------------------+-----------------------------+
 *       title                      |                             |
 * ---------------------------------+      barcode2               |
 *       barcode1                   |      (UPC-A)                |
 *   (model number, code 128)       |                             |
 * ---------------------------------------------------------------+
 *                                                                |
 *                          SCC-14 code (barcode 3)               |
 * ---------------------------------------------------------------+                           
 *                          PARAGRAPH 1                           |
 * ---------------------------------------------------------------+
 *                          barcode 4                             |
 *                  (serial number, code 128)                     |
 * ---------------------------------------------------------------+
 *                          PARAGRAPH 2                           |
 * ---------------------------------------------------------------+
 */ 

public class CaseCodeLabel : PrintDocument
{
	private string _upc_number;
	private string _scc_14_number;
	private string _model_number;
	private string _serial_number;
	private BarcodeDLLImport _barcode;

	private float _top_margin; //top margin in inch
	private float _left_margin; //left margin in inch

	public CaseCodeLabel(string upc_code, string scc_14, string model, string serial,
		BarcodeDLLImport barcode)
	{
		_upc_number = upc_code;
		_scc_14_number = scc_14;
		_model_number = model;
		_serial_number = serial;
		_barcode = barcode;

		_top_margin = 0.25f;
		_left_margin = 0.25f;
	}

	protected void DrawTitle(Graphics graphics)
	{
		string strTitle = "Morovia\r\nG890A";

		graphics.PageUnit = GraphicsUnit.Point;
		Font fntTitle = new Font("Arial Black", 16);
		StringFormat sf = new StringFormat();
		sf.Alignment = StringAlignment.Center;
		sf.LineAlignment = StringAlignment.Center;
		RectangleF rc = new RectangleF(new PointF(_left_margin*72, _top_margin*72),
			new SizeF(2.0f*72, 0.50f*72));
		
		graphics.DrawString(strTitle, fntTitle, Brushes.Black, rc, sf);
	}

	protected SizeF DrawModelNumber(Graphics graphics)
	{
		// the model number barcode params: no comment, no hr, 1 cm in height
		_barcode.Symbology = 5;					//mbxCode128;
		_barcode.Measurement = 1;				//mbxMeasureMetrics;
		_barcode.BarHeight = 1000;
		_barcode.BearerBars = false;
		_barcode.ShowHRText = false;
		_barcode.NarrowBarWidth = 25;
		_barcode.AutoSize = true;
		_barcode.message = _model_number;
	
		System.Drawing.Image emf = ConvertImage.Convert(_barcode.Picture);
		//switch barcode unit to 1/1000 inch
		_barcode.Measurement = 0;				//mbxMeasureEnglish;
		graphics.PageUnit = GraphicsUnit.Inch;
		float start_x = _left_margin;
		float start_y = _top_margin+0.50f;
		graphics.DrawImage(emf, start_x, start_y);

		SizeF sf = new SizeF(_barcode.LabelWidth/1000.0f, _barcode.LabelHeight/1000.0f);
		return sf;
	}

	protected void DrawUPCNumber(Graphics graphics, float pos_y_bottom)
	{
		// upc code params: no comment, with hr, 0.75 inch in height
		_barcode.Symbology = 8;		// mbxUPC_A;
		_barcode.Measurement = 0;   // mbxMeasureEnglish;
		_barcode.BarHeight = 750;
		_barcode.ShowHRText = true;
		_barcode.BearerBars = false;
		_barcode.message = _upc_number;

		System.Drawing.Image emf = ConvertImage.Convert(_barcode.Picture);
		
		float pos_x = _left_margin + 2.0f + (1.5f-_barcode.LabelWidth/1000.0f)/2;
		float pos_y = pos_y_bottom - _barcode.LabelHeight/1000.0f;
		graphics.DrawImage(emf, pos_x, pos_y );
	}

	protected SizeF DrawSCC14Number(Graphics graphics, float pos_y_top)
	{
		// scc-14 barcode: no comment, with hr, bearer bars, 0.75 height
		_barcode.Symbology = 7;   // mbxInterleaved_2of5;
		_barcode.Measurement = 0; // mbxMeasureEnglish;
		_barcode.BarHeight = 750;
		_barcode.NarrowBarWidth = 20;
		_barcode.BearerBars = true;
		_barcode.ShowHRText = true;
		_barcode.message = _scc_14_number;
		Image emf = ConvertImage.Convert(_barcode.Picture);
	
		float pos_x = _left_margin + (3.5f - _barcode.LabelWidth/1000.0f)/2;
		float pos_y = pos_y_top;
		graphics.DrawImage(emf, pos_x, pos_y);

		SizeF sf = new SizeF(_barcode.LabelWidth/1000.0f, _barcode.LabelHeight/1000.0f);
		return sf;
	}

	protected SizeF DrawTextPara1(Graphics graphics, float pos_y_top)
	{
		string strPara = "MODEL NUMBER: " + _model_number  
			+ "\r\n" + "SERIAL NUMBER: " + _serial_number;

		Font fntPara = new Font("Arial Black", 10.0f);
		StringFormat sf = new StringFormat();
		sf.Alignment = StringAlignment.Center;
		sf.LineAlignment = StringAlignment.Near;
		
		SizeF size_f = graphics.MeasureString(strPara, fntPara, new PointF(0,0), sf);
		RectangleF rc = new RectangleF(new PointF(_left_margin, pos_y_top),
			new SizeF(3.5f, size_f.Height));
		graphics.DrawString(strPara, fntPara, Brushes.Black, rc, sf);
		return size_f;
	}

	protected SizeF DrawSerialNumber(Graphics graphics, float pos_y_top)
	{
		// serial number: no comment, no hr, no bearer bars, 0.75 inch height
		_barcode.Symbology = 5;   // mbxCode128;
		_barcode.Measurement = 0; // mbxMeasureEnglish;
		_barcode.BarHeight = 500;
		_barcode.NarrowBarWidth = 20;
		_barcode.BearerBars = false;
		_barcode.ShowHRText = false;
		_barcode.message = _serial_number;
		Image emf = ConvertImage.Convert(_barcode.Picture);

		float barcode_width = _barcode.LabelWidth/1000.0f;
		float start_x = _left_margin+(3.5f-barcode_width)/2.0f;
		graphics.DrawImage(emf, start_x, pos_y_top );

		SizeF sf = new SizeF(_barcode.LabelWidth/1000.0f, _barcode.LabelHeight/1000.0f);
		return sf;
	}

	public void Draw(Graphics graphics, float xPos, float yPos)
	{
		DrawTitle(graphics);
		SizeF size_f = DrawModelNumber(graphics);
		float pos_y = size_f.Height+0.5f+_top_margin;
	
		DrawUPCNumber(graphics, pos_y);

		size_f = DrawSCC14Number(graphics, pos_y);

		pos_y += size_f.Height;

		size_f = DrawTextPara1(graphics, pos_y);

		pos_y += size_f.Height;

		size_f = DrawSerialNumber(graphics, pos_y);

		pos_y += size_f.Height;

		DrawPara2(graphics, pos_y);
	}

	protected void DrawPara2(Graphics graphics, float pos_y_top)
	{
		string strPara1 = "Made in Canada";
		string strPara2 = "SEPTEMBER 2006 I";		

		Font fntPara = new Font("Arial Black", 10.0f);
		StringFormat sf = new StringFormat();
		sf.Alignment = StringAlignment.Near;
		sf.LineAlignment = StringAlignment.Near;

		RectangleF rc = new RectangleF(new PointF(_top_margin, pos_y_top), new SizeF(2.0f, 1.0f));
		graphics.DrawString(strPara1, fntPara, Brushes.Black, rc, sf);

		sf.Alignment = StringAlignment.Far;
		rc = new RectangleF(new PointF(_top_margin+1.5f, pos_y_top), new SizeF(2.0f, 1.0f));
		graphics.DrawString(strPara2, fntPara, Brushes.Black, rc, sf);
	}

	// ShowPreview - show a print preview... 
	public void ShowPreview() 
	{ 
		// now, show the print dialog... 
		PrintPreviewDialog dialog = new PrintPreviewDialog(); 
		dialog.Document = this; 

		// show the dialog... 
		dialog.ShowDialog(); 
	} 

	// ShowPrintDialog - display the print dialog... 
	public void PrintDirect() 
	{ 
		// create and show... 
		PrintDialog dialog = new PrintDialog(); 
		dialog.PrinterSettings = PrinterSettings; 
		dialog.Document = this; 
		if(dialog.ShowDialog() == DialogResult.OK) 
		{ 
			// save the changes... 
			PrinterSettings = dialog.PrinterSettings; 

			// do the printing... 
			Print(); 
		} 
	} 

	protected override void OnBeginPrint(PrintEventArgs e)
	{
	}

	protected override void OnPrintPage(PrintPageEventArgs e) 
	{
		Draw(e.Graphics, 0, 0);
	}
}
